/****************************************************************************
  File:  qfont.c
  Module:  AzaleaQTools

  Prototype:  BYTE SymbolToFont(BYTE symbol)
  Revision History:
    14Sep00  Cory R. King (coryking@azalea.com)
        Created based on Azalea Software's existing barcode library and sample
        code.


  Description:  Performs QTools Symbol value to Azalea Font value conversion.
        Correct for Version 4.0 fonts; can be used with prior font versions by
        #define-ing OLD_FONTS.

        The table maps Decimal value and corresponding ASCII character
        for Codesets A and B, and Symbol Value ( == packed digit pair value
        for digit pairs 00 to 99) for Codeset C, to Azalea Font value.


  This code is held under a GNU licence.  C128Tools is a registered trademark
  of Azalea Software, Inc.
****************************************************************************/
#include "platform.h"

const BYTE QFONT[] = {


// Symbol Value:   00  01  02  03  04  05  06  07  08  09
/* Font Value */  194, 33, 34, 35, 36, 37, 38, 39, 40, 41,

// Symbol Value:   10  11  12  13  14  15
/* Font Value */   42, 43, 44, 45, 46, 47,

// Symbol Value:   16  17  18  19  20  21  22  23  24  25
/* Font Value */   48, 49, 50, 51, 52, 53, 54, 55, 56, 57,

// Symbol Value:   26  27  28  29  30  31  32
/* Font Value */   58, 59, 60, 61, 62, 63, 64,

// Symbol Value:   33  34  35  36  37  38  39  40  41
/* Font Value */   65, 66, 67, 68, 69, 70, 71, 72, 73,

// Symbol Value:   42  43  44  45  46  47  48  49  50
/* Font Value */   74, 75, 76, 77, 78, 79, 80, 81, 82,

// Symbol Value:   51  52  53  54  55  56  57  58
/* Font Value */   83, 84, 85, 86, 87, 88, 89, 90,

// Symbol Value:   59  60  61  62  63
/* Font Value */   91, 92, 93, 94, 95,

// Symbol Value:   64
/* Font Value */   96,

// Symbol Value:   65   66  67   68   69   70   71   72   73
/* Font Value */   97,  98, 99, 100, 101, 102, 103, 104, 105,

// Symbol Value:   74   75   76   77   78   79   80   81   82
/* Font Value */  106, 107, 108, 109, 110, 111, 112, 113, 114,

// Symbol Value:   83   84   85   86   87   88   89   90
/* Font Value */  115, 116, 117, 118, 119, 120, 121, 122,

// Symbol Value:   91   92   93   94   95
/* Font Value */  123, 124, 125, 185, 186,

// Symbol Value:   96   97    98     99
/* Font Value */  187, 188,  189,   190,

// Symbol Value:  100    101
/* Font Value */  191,   192,

// Symbol Value:  102
/* Font Value */  193,

// This font does not contain start bars
// Symbol Value:     103     104     105
/* Font Value */     32,    32,    32,

// Symbol Value:   106
/* Font Value */   184,

}; /* end QFONT[] */

char Q_STOP    = 106;
char Q_START   = 01;

BYTE SymbolToFont(BYTE symbol)
{
    return QFONT[symbol];
}

// for debug/test only: reveal table size for reverse lookup
short table_size = sizeof(QFONT) / sizeof(QFONT[0]);

/* end qfont.c */

